@@ -70,7 +70,7 @@ class VirtualMachineInstancetype(NamespacedResource):
     def to_dict(self) -> None:
         super().to_dict()
 
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             if not all([
                 self.cpu,
                 self.memory,
